@@ -11,9 +11,9 @@ test_that("compile (compressed formulation)", {
   n_pu <- length(sim_pu_raster[[1]][!is.na(sim_pu_raster)])
   n_features <- raster::nlayers(sim_features)
   scaled_costs <- p$planning_unit_costs()
-  scaled_costs <- scaled_costs * (1e-10 / min(scaled_costs))
+  scaled_costs <- scaled_costs * (-1e-10 / min(scaled_costs))
   expect_equal(o$modelsense(), "max")
-  scaled_costs <- scaled_costs * (1e-10 / min(scaled_costs))
+  expect_equal(o$obj(), c(scaled_costs, rep(1, n_features)))
   expect_equal(o$sense(), c(rep("=", n_features), "<="))
   expect_equal(o$rhs(), c(rep(0, n_features), b))
   expect_equal(o$col_ids(), c(rep("pu", n_pu), rep("amount", n_features)))
@@ -65,9 +65,9 @@ test_that("compile (expanded formulation)", {
   n_f <- raster::nlayers(sim_features)
   rij <- rij_matrix(sim_pu_raster, sim_features)
   scaled_costs <- p$planning_unit_costs()
-  scaled_costs <- scaled_costs * (1e-10 / min(scaled_costs))
+  scaled_costs <- scaled_costs * (-1e-10 / min(scaled_costs))
   expect_equal(o$modelsense(), "max")
-  scaled_costs <- scaled_costs * (1e-10 / min(scaled_costs))
+  expect_equal(o$obj(), c(scaled_costs, rep(0, n_pu * n_f), rep(1, n_f)))
   expect_equal(o$sense(), c(rep("<=", n_pu * n_f), rep( "=", n_f), "<="))
   expect_equal(o$rhs(), c(rep(0, n_f * n_pu), rep(0, n_f), b))
   expect_equal(o$col_ids(), c(rep("pu", n_pu), rep("pu_ij", n_pu * n_f),
